aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--core/vm/gas_table.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/vm/gas_table.go b/core/vm/gas_table.go
index 6400c1324..8b034a0e7 100644
--- a/core/vm/gas_table.go
+++ b/core/vm/gas_table.go
@@ -32,11 +32,11 @@ func memoryGasCost(mem *Memory, newMemSize uint64) (uint64, error) {
// The maximum that will fit in a uint64 is max_word_count - 1
// anything above that will result in an overflow.
// Additionally, a newMemSize which results in a
- // newMemSizeWords larger than 0x7ffffffff will cause the square operation
+ // newMemSizeWords larger than 0xFFFFFFFF will cause the square operation
// to overflow.
// The constant 0xffffffffe0 is the highest number that can be used without
// overflowing the gas calculation
- if newMemSize > 0xffffffffe0 {
+ if newMemSize > 0x1FFFFFFFE0 {
return 0, errGasUintOverflow
}
@@ -32,11 +32,11 @@ func memoryGasCost(mem *Memory, newMemSize uint64) (uint64, error) {
// to overflow.
- // The constant 0xffffffffe0 is the highest number that can be used without
+ // The constant 0x1FFFFFFFE0 is the highest number that can be used without
// overflowing the gas calculation